Learn R Programming

DPpackage (version 1.1-6)

sports: The Australian Athletes Data

Description

This data set consider information from 202 elite Australian athletes who trained at the Australian Institute of Sport. The members of the sample participate in a number of different sports and are about equally split between men and women.

Usage

data(sports)

Arguments

Format

A data frame with 202 observations on the following 13 variables.
gender
a factor with levels female and male
sport
a factor with levels B_Ball, Field, Gym, Netball, Row, Swim, T_400m, T_Sprnt, Tennis, and W_Polo
rcc
a numeric vector giving the red cell count
wcc
a numeric vector giving the white cell count
Hc
a numeric vector giving the Hematocrit
Hg
a numeric vector giving the Hemoglobin level
Fe
a numeric vector giving the plasma ferritin concentration
bmi
a numeric vector giving the body mass index, weight/(height)**2
ssf
a numeric vector giving the sum of skin folds
Bfat
a numeric vector giving the body fat percentage
lbm
a numeric vector giving the lean body mass
Ht
a numeric vector giving the height (cm)
Wt
a numeric vector giving the weight (Kg)

Cook and Weisberg (1994), An Introduction to Regression Graphics. John Wiley & Sons, New York.

References

Cook and Weisberg (1994), An Introduction to Regression Graphics. John Wiley & Sons, New York.

Examples

Run this code
data(sports)
## maybe str(sports) ; plot(sports) ...

Run the code above in your browser using DataLab