A data frame with 202 observations on the following 13 variables.
gendera factor with levels female and male
sporta factor with levels B_Ball, Field, Gym, Netball,
Row, Swim, T_400m, T_Sprnt, Tennis,
and W_Polo
rcca numeric vector giving the red cell count
wcca numeric vector giving the white cell count
Hca numeric vector giving the Hematocrit
Hga numeric vector giving the Hemoglobin level
Fea numeric vector giving the plasma ferritin concentration
bmia numeric vector giving the body mass index, weight/(height)**2
ssfa numeric vector giving the sum of skin folds
Bfata numeric vector giving the body fat percentage
lbma numeric vector giving the lean body mass
Hta numeric vector giving the height (cm)
Wta numeric vector giving the weight (Kg)